function md=solveparallel(md,options)
%SOLVEPARALLEL - solution sequence using a cluster in parallel mode
%
%   Usage:
%      md=solveparallel(md);

%First, build a runtime name that is unique, that we will use to create 
%directories, name jobs, etc ...
c=clock;
md.runtimename=sprintf('%s-%i-%i-%i-%i-%i-%i',md.name,GetPId,c(2),c(3),c(1),c(4),c(5));

%Marshall model data into a binary file.
marshall(md);

%add qmu fields to binary file if running qmu analysis
if md.qmu_analysis,
	qmumarshall(md,md.variables(options.ivar),md.responses(options.iresp));
end

%Now, we need to build the queuing script, used by the cluster to launch the job.
BuildQueueScript(md.cluster,md.name,md.analysis_type,md.mem_debug);

%Now, launch the queueing script
LaunchQueueJob(md,options);

%Do we return, or just wait for results?
if (md.waitonlock~=0 &  ~strcmpi(options.batch,'yes')),
	%we wait for the done file
	islock=waitonlock(md);
	if islock==0,
		%no results to be loaded
		disp('The results must be loaded manually with md=loadresultsfromcluster(md).');
	else
		%load results
		displaystring(md.verbose,'loading results from cluster');
		md=loadresultsfromcluster(md);
	end
end

%post processes qmu results if necessary
if md.qmu_analysis,
	system(['rm -rf qmu' num2str(GetPId)]);
end


